summaryrefslogtreecommitdiffstats
path: root/scripts
diff options
context:
space:
mode:
Diffstat (limited to 'scripts')
-rwxr-xr-xscripts/mobilecomponents.sh10
1 files changed, 5 insertions, 5 deletions
diff --git a/scripts/mobilecomponents.sh b/scripts/mobilecomponents.sh
index 590481468..6d535fa26 100755
--- a/scripts/mobilecomponents.sh
+++ b/scripts/mobilecomponents.sh
@@ -14,17 +14,17 @@ if [ ! -d "$SRC/subsurface" ] || [ ! -d "qt-mobile" ] || [ ! -d "subsurface-core
exit 1
fi
# now bring in the latest Plasma-mobile mobile components plus a couple of icons that we need
# first, get the latest from upstream
# yes, this is a bit overkill as we clone a lot of stuff for just a few files, but this way
# we stop having to manually merge our code with upstream all the time
# as we get closer to shipping a production version we'll likely check out specific tags
# or SHAs from upstream
cd $SRC
-if [ ! -d plasma-mobile ] ; then
- git clone git://github.com/KDE/plasma-mobile
+if [ ! -d kirigami ] ; then
+ git clone git://github.com/KDE/kirigami
fi
-pushd plasma-mobile
+pushd kirigami
git pull
popd
if [ ! -d breeze-icons ] ; then
@@ -36,7 +36,7 @@ popd
# now copy the components and a couple of icons into plae
MC=$SRC/subsurface/qt-mobile/qml/mobilecomponents
-PMMC=plasma-mobile/components/mobilecomponents
+PMMC=kirigami/src
BREEZE=breeze-icons
rm -rf $MC
@@ -14,17 +14,17 @@ if [ ! -d "$SRC/subsurface" ] || [ ! -d "qt-mobile" ] || [ ! -d "subsurface-core
exit 1
fi
-# now bring in the latest Plasma-mobile mobile components plus a couple of icons that we need
+# now bring in the latest Kirigami mobile components plus a couple of icons that we need
# first, get the latest from upstream
# yes, this is a bit overkill as we clone a lot of stuff for just a few files, but this way